<?php
/** Lazuri (Lazuri)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Bombola
 * @author Dato deutschland
 * @author Dawid Deutschland
 * @author Ibero-kolxi
 * @author The Evil IP address
 */

$fallback = 'tr';

$messages = array(
# User preference toggles
'tog-underline'        => "Link'iş tude kogu3’uxaçki:",
'tog-highlightbroken'  => 'Upşu linkepe <a href="" class="new">am şekilite</a> (alternatifi: am şekilite<a href="" class="internal">?</a>) ko3\'iri.',
'tog-rememberpassword' => 'Parola-skani goişini (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-showhiddencats'   => "Şinaxeri k'at'egorepe ko3'iri",

'underline-always' => "P'anda",
'underline-never'  => "P'ot'e",

# Dates
'sunday'        => 'Mjaçxa',
'monday'        => 'Tutaçxa',
'tuesday'       => 'İk’inaçxa',
'wednesday'     => 'Cumaçxa',
'thursday'      => 'Çaçxa',
'friday'        => 'Obiçxa',
'saturday'      => 'Sabat’oni',
'sun'           => 'Mja',
'mon'           => 'Tut',
'tue'           => "İk'i",
'wed'           => 'Cum',
'thu'           => 'Çaç',
'fri'           => 'Obi',
'sat'           => 'Sab',
'january'       => '3ʼanağani',
'february'      => 'Kʼundura',
'march'         => 'Martʼi',
'april'         => 'Apʼrili',
'may_long'      => 'Maisi',
'june'          => 'Mbuliştuta',
'july'          => 'X3ala',
'august'        => 'Maraşina',
'september'     => 'Stʼaroşina',
'october'       => 'Gumatuta',
'november'      => 'Çxalva',
'december'      => 'Xristʼana',
'january-gen'   => '3ʼanağani',
'february-gen'  => 'Kʼundura',
'march-gen'     => 'Martʼi',
'april-gen'     => 'Apʼrili',
'may-gen'       => 'Maisi',
'june-gen'      => 'Mbuliştuta',
'july-gen'      => 'X3ala',
'august-gen'    => 'Maraşina',
'september-gen' => 'Stʼaroşina',
'october-gen'   => 'Gumatuta',
'november-gen'  => 'Çxalva',
'december-gen'  => 'Xristʼana',
'jan'           => '3ʼan',
'feb'           => 'Kʼun',
'mar'           => 'Mar',
'apr'           => 'Apʼr',
'may'           => 'Mai',
'jun'           => 'Mbul',
'jul'           => 'X3al',
'aug'           => 'Mara',
'sep'           => 'Stʼa',
'oct'           => 'Gum',
'nov'           => 'Çxa',
'dec'           => 'Xri',

# Categories related messages
'pagecategories'                => 'Butʼkʼaşi {{PLURAL:$1|kʼatʼegori|kʼatʼegorepe}}',
'category_header'               => '"$1" kʼatʼegoris butʼkʼape',
'subcategories'                 => 'Tudekʼategorepe',
'category-media-header'         => '"$1" k\'at\'egoris media',
'category-empty'                => "''Am k'at'egoris çkar madde varna media va uğun.''",
'hidden-categories'             => '{{PLURAL:$1|Şinaxeri kʼatʼegori|Şinaxeri kʼatʼegorepe}}',
'hidden-category-category'      => "Şinaxeri k'at'egorepe",
'category-subcat-count'         => '{{PLURAL:$2|Am kʼatʼegoris, xvala, tude na ren kʼatʼegori uğun.|Am kʼatʼegori tʼoplamurot $2 kʼatʼegorişen {{PLURAL:$1|tudekʼatʼegori|$1 tudekʼatʼegori}}s uğun}}',
'category-subcat-count-limited' => "Am k'at'egori tudes na dgin {{PLURAL:$1|tude k'at'egoris|$1 tude k'at'egoris}} uğun.",
'category-article-count'        => '{{PLURAL:$2|Am kʼatʼegoris, xvala, tude na ren kʼatʼegori uğun.|Tʼoplami $2 şen, tude na ren {{PLURAL:$1|butʼkʼa|$1 butʼkʼa}} am kʼatʼegoris ren.}}',
'listingcontinuesabbrev'        => '(naqona)',
'index-category'                => "Indexi na uğun but'k'ape",
'noindex-category'              => 'Indexi muşi na var uğun sayfape',

'about'         => 'Şeni',
'newwindow'     => '(ağne penceres guin3ʼkʼen)',
'cancel'        => 'İpʼtʼali qʼvi',
'moredotdotdot' => 'Çkva…',
'mypage'        => 'Çkimi sayfa',
'mytalk'        => 'Çkimi mesajepe',
'anontalk'      => "Am IP'şi mesajepe",
'navigation'    => 'Goxtima',
'and'           => '&#32;do',

# Cologne Blue skin
'qbfind'         => 'Koz*iri',
'qbedit'         => 'Doktiri',
'qbpageoptions'  => 'Am sayfa',
'qbmyoptions'    => 'Çkimi sayfape',
'qbspecialpages' => 'Doxmeli sayfape',

# Vector skin
'vector-action-delete' => 'Jili',
'vector-view-edit'     => 'Doktiri',

'errorpagetitle'   => 'Çilata',
'returnto'         => '$1 butʼkʼaşa goikti.',
'tagline'          => '{{SITENAME}}-işen',
'help'             => 'Meşvela',
'search'           => 'mgori',
'searchbutton'     => 'Mgori',
'go'               => 'İgzali',
'searcharticle'    => 'İgzali',
'history'          => 'Butʼkʼaş tarixi',
'history_short'    => 'Tarixi',
'printableversion' => "Kart'alişa na geibaz*gen versiyoni",
'permalink'        => 'Am xalişa kʼontaktʼi qʼvi',
'edit'             => 'doktiri',
'create'           => 'dokʼidi',
'editthispage'     => 'Butʼkʼa doktiri',
'delete'           => 'Jili',
'deletethispage'   => 'Am sayfa jili',
'protect'          => 'İçvi',
'protect_change'   => 'Doktiri',
'newpage'          => 'Ağani butʼkʼa',
'talkpage'         => 'Butʼkʼas ğarğali.',
'talkpagelinktext' => 'Mesaji',
'specialpage'      => 'Doxmeli sayfa',
'personaltools'    => 'Doxmeli oxmaronepe',
'talk'             => 'Ğarğala',
'views'            => 'Oz*iramepe',
'toolbox'          => 'Oxmaronepe',
'otherlanguages'   => 'Majurani nenapes',
'redirectedfrom'   => '($1 butʼkʼaşen moxtu)',
'redirectpagesub'  => 'Redirektʼiş butʼkʼa',
'lastmodifiedat'   => 'Am butʼkʼa çodinurot $2, $1 tarixis iktirinu.',
'jumpto'           => 'İdi do:',
'jumptonavigation' => 'ixmari',
'jumptosearch'     => 'mgori',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} şeni',
'aboutpage'            => 'Project:Ambarepe',
'copyright'            => 'Doloxe na renanpe, $1-şi ren.',
'copyrightpage'        => '{{ns:project}}:Şinaxeri Hakʼepe',
'disclaimers'          => 'Kʼabuli na var ixvenu ondepe',
'disclaimerpage'       => 'Project:Mtelot kʼabuli na var ixvenu ondepe',
'edithelp'             => 'Muçʼoşi iktirinen?',
'edithelppage'         => 'Help:Butʼkʼa muçʼoşi iktirinen?',
'helppage'             => 'Help:Doloxe na renanpe',
'mainpage'             => 'Dudi Butʼkʼa',
'mainpage-description' => "Dudi But'k'a",
'privacy'              => 'Şinaxeri Hakʼepe',
'privacypage'          => 'Project:Şinaxeri Hakʼepe',

'badaccess' => 'İzini çilata',

'ok'                      => 'HO',
'retrievedfrom'           => '"$1" adresişen eizdinu',
'youhavenewmessages'      => 'Ağani <u>$1</u> giğun. ($2)',
'newmessageslink'         => 'ağani mesajepe',
'newmessagesdifflink'     => 'çodinaşi oktiroba',
'youhavenewmessagesmulti' => "$1's ağne mesajepe giğun",
'editsection'             => 'doktiri',
'editold'                 => 'Doktiri',
'editlink'                => 'Doktiri',
'viewsourcelink'          => 'odude koz*iri',
'editsectionhint'         => '$1 burme muşi doktiri',
'toc'                     => 'Temaşi dudi-coxope',
'showtoc'                 => 'ko3ʼiri',
'hidetoc'                 => 'Doşinaxi',
'site-rss-feed'           => '$1 RSS-iş Feedi',
'site-atom-feed'          => '$1 Atʼom-iş feedi',
'page-rss-feed'           => '"$1" RSS-iş Feedi',
'page-atom-feed'          => '"$1" Atʼom-iş Feedi',
'red-link-title'          => '$1 (Ak butʼkʼa va ren)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Stʼatʼia',
'nstab-user'      => 'maxmareş butʼkʼa',
'nstab-special'   => 'Doxmeli butʼkʼa',
'nstab-project'   => 'Pʼrojeşi butʼkʼa',
'nstab-image'     => 'Dosya',
'nstab-mediawiki' => 'Mesaji',
'nstab-template'  => 'Şabloni',
'nstab-category'  => 'Kʼatʼegori',

# General errors
'missing-article'    => 'Datʼabeizik, na igoren "$1" $2 coxoni butʼkʼaşi tekstʼi var az*iru.

Muşeni? Çunki am butʼkʼa, jileri na ren a butʼkʼaşi golaxteri versiyoni ren.

Eger sebebi aya na va renna, pʼrogramis ar çilata z*irit.
Mu iqʼven! Aya, a [[Special:ListUsers/sysop|adminis]], URL-ti çʼareli şekʼilite rapʼortʼi doçʼarit.',
'missingarticle-rev' => '(revizyoni#: $1)',
'badtitletext'       => 'Na içʼaren butʼkʼaşi coxo ya çilatoni ren ya boşi ren varna inter-nena do inter-vikʼişi kʼontʼaktʼis na uğutʼu şeni mtini varen.
Dudicoxopes oxmaruşi yasaği na ren ar, varna daha dido kʼarakʼtʼeri uğun.',
'viewsource'         => 'Odudes o3ʼkʼedi',

# Login and logout pages
'yourname'                => 'Skani maxmare-coxo:',
'yourpassword'            => 'Pʼarola-skani:',
'remembermypassword'      => 'Parola-skani goişini (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'                   => 'Sitʼeşa amaxti',
'nav-login-createaccount' => 'Sitʼeşa amaxti / hesabi dokʼidi',
'userlogin'               => 'Sitʼeşa amaxti / hesabi dokʼidi',
'logout'                  => 'Siteşen Kogamaxti',
'userlogout'              => 'Siteşen Kogamaxti',
'nologin'                 => "Hesabi va giğuni? '''$1'''",
'nologinlink'             => 'Hesabi dokʼidi.',
'mailmypassword'          => 'Ağne pʼarola-çkimi moncğoni',

# Change password dialog
'oldpassword' => "Mcveşi p'arola:",
'newpassword' => "Ağani P'arola:",

# Edit page toolbar
'bold_sample'     => 'Mçxu nçʼara',
'bold_tip'        => 'Mçxu nçʼara',
'italic_sample'   => 'Elakteri nçʼara',
'italic_tip'      => 'Elakteri nçʼara',
'link_sample'     => 'Kʼontʼaktʼiş dudicoxo',
'link_tip'        => 'Doloxeni linkʼi',
'extlink_sample'  => 'http://www.example.com adresiş oxo3ʼonapa',
'extlink_tip'     => 'Galeni kʼontʼaktʼi (Adresiş dudis http:// ukʼatit)',
'headline_sample' => 'Dudicoxoşi nçʼara',
'headline_tip'    => '2. derece dudicoxo',
'nowiki_sample'   => 'Oxoşkveri formatʼi nçʼara-tkvani ak doçʼarit.',
'nowiki_tip'      => 'vikʼiş formatʼi ipʼtʼali qʼvi.',
'image_tip'       => 'Doxveri dosya',
'media_tip'       => 'Media dosyasişa kʼontʼaktʼi',
'sig_tip'         => 'Xeşçʼara-tkvani do tarixi',
'hr_tip'          => 'Horizontʼali ğara (m3ika ixmarit)',

# Edit pages
'summary'                          => 'Mkʼule nçʼarate:',
'subject'                          => 'Tema/dudi-coxo:',
'minoredit'                        => 'Çʼitʼa oktiroba',
'watchthis'                        => 'Butkʼa gatxozi',
'savearticle'                      => 'Butʼkʼas ikʼayitʼi',
'preview'                          => 'Evvelişen i3ʼkʼedi',
'showpreview'                      => '"Evvelişen i3ʼkʼedi" fonkʼsioni ixmari',
'showdiff'                         => 'Oktirobape ko3ʼiri',
'anoneditwarning'                  => "'''KUN3Xİ:''' Sitʼeşa amaxtimeri va re.
Emuşeni butʼkʼaşi oktirobaşi kʼayitʼepes, coxoskani yeine IP adresiskani ikʼayitʼinasen.",
'summary-preview'                  => '"Evvelişen i3ʼkʼedi" fonkʼsionişi ozetʼi:',
'newarticle'                       => '(Ağani)',
'newarticletext'                   => "Daha na va ren ar butʼkʼaşa na geidven ar kʼontʼaktʼis atxozit. Am butʼkʼa okʼidu şeni tude na ren tʼeksboksi ixmarit. Çkina şeni [[{{MediaWiki:Helppage}}|meşvelaşi butʼkʼas]] o3ʼkʼedit. Ak çilataten moxtit na, pʼrogramişi '''Ukʼuni''' tʼuşis geibaz*git.",
'noarticletext'                    => 'A3ʼi am butʼkʼa boşi ren.
Am butʼkʼaş dudi-coxo majurani butʼkʼapes [[Special:Search/{{PAGENAME}}|gagoren]],
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} alakʼali na renan ndğerepe gagoren],
varna am butʼkʼa [{{fullurl:{{FULLPAGENAME}}|action=edit}} gaktirinen]</span>.',
'previewnote'                      => "'''Aya, xvala, \"Evvelişen i3ʼkʼedi\" fonkʼsioni ren do oktirobape-skani kʼayitʼi var ixvenu çkva!'''",
'editing'                          => '"$1" butʼkʼa iktirinen a3ʼi',
'editingsection'                   => '"$1" butʼkʼas burme iktirinen',
'copyrightwarning'                 => "'''Mu iqʼven kʼun3xi:''' {{SITENAME}} sitʼeşa na ixvenu mteli meşvelape <i>$2</i>
paktʼiş doloxe ren (detayepe şeni $1's o3ʼkʼedi).
Na qʼvi meşvelaşa başka makʼaturepeşkʼelen pʼatʼi mutxanepe ixvenen varna xemoşletinerot do uoçodinurot başka svapeşa niçinen, aya kʼabuli qʼvi varna am sitʼe şeni mutu mo ikip!<br />
Edo amuş metʼi, ak mxuciş meçamu ginonna, meşvelape ti-skani kʼala oçʼaruşi re, varna ofi3ialurişa gon3ʼkʼimeri na ren ar kʼaynağişen (odudeşen) varna başka oxoşkveri kʼaynağepeşen (odudepeşen) na ezdi kʼabuli oxvenuşi re.<br />
'''<center>DOXMELİ HAKʼEPETE NA İŞİNAXENAN XANDAPE AK MO UKʼATEPT!</center>'''",
'templatesused'                    => 'Am butʼkʼas na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
'templatesusedpreview'             => 'Am "Evvelişen i3ʼkʼedi" fonkʼsionis na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
'template-protected'               => '(oçvu)',
'template-semiprotected'           => '(gverd-oçvu)',
'hiddencategories'                 => 'Am butʼkʼa {{PLURAL:$1|1 şinaxeri kʼatʼegori|$1 şinaxeri kʼatʼegori}}şi ren:',
'permissionserrorstext-withaction' => 'Tude na çʼars {{PLURAL:$1|sebebi|sebebepe}} na rtʼu şeni $2 yetʼkʼi var giğun:',

# History pages
'viewpagelogs'           => 'Am butʼkʼa şeni kʼayitʼepe ko3ʼiri',
'currentrev-asof'        => '$1 itibariten butʼkʼaşi a3ʼineri xali.',
'revisionasof'           => 'Butʼkʼaşi $1 tarixis xali muşi',
'previousrevision'       => '← Mcveşi xali muşi',
'nextrevision'           => 'Ağani xali-muşi →',
'currentrevisionlink'    => 'İrişen ağne xali-muşi ko3ʼiri',
'cur'                    => 'farkʼi',
'last'                   => 'çodina',
'histlegend'             => 'Farkʼiş 3xuna: o3xunu şeni na ginon 2 versiyoniş na go3ʼadgin dairepeşa gebaz*gi, do ukvule entʼerişa gebaz*gi varna butʼkʼaşi tude na dgin tʼuşişa gebaz*gi.<br />
Oxo3ʼonapape: (a3ʼineri) = a3ʼineri versiyoni kʼala na ren farkʼi,
(iptineri) = iptineri versiyoni kʼala na ren farkʼi, Çʼ = çʼitʼa oktiroba.',
'history-fieldset-title' => 'Golaxteris o3ʼkʼedi',
'histfirst'              => 'irişen mcveşi',
'histlast'               => 'irişen ağani',

# Revision deletion
'rev-delundel'          => 'ko3ʼiri/doşinaxi',
'revdelete-radio-set'   => 'Ho',
'revdelete-radio-unset' => 'Var',
'revdel-restore'        => 'Ozʼiramuşi doktiri',

# Merge log
'revertmerge' => 'Artikʼartişen okʼo3ʼkʼi',

# Diffs
'history-title'           => '"$1" butʼkʼaşi tarixi',
'difference'              => '(Versiyonepeşi farkʼepe)',
'lineno'                  => '$1. satʼiri:',
'compareselectedversions' => 'Na goşiğen versiyonepe okʼo3ʼiri',
'editundo'                => 'ukʼuni',

# Search results
'searchresults'             => 'Ogoru sonucepe',
'searchresults-title'       => '"$1" şeni ogoru sonucepe',
'searchresulttext'          => '{{SITENAME}}-iş doloxe ogoru temas, mutxanepe oguru şeni [[{{MediaWiki:Helppage}}|{{int:help}}]] coxoni butʼkʼas o3ʼkʼedit.',
'searchsubtitle'            => 'Si \'\'\'[[:$1]]\'\'\' şeni gori. ([[Special:Prefixindex/$1|"$1" kʼala na gyoçʼkʼaps mtel butʼkʼape]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|"$1"\' butʼkʼa muşişa kʼontʼaktʼi na ikips mtel butʼkʼape]])',
'searchsubtitleinvalid'     => "'''$1''' şeni mgori",
'notitlematches'            => 'Çkar svas var iz*irinu',
'notextmatches'             => 'Çkar butʼkʼa var iz*irinu',
'prevn'                     => 'ukʼuni {{PLURAL:$1|$1}}',
'nextn'                     => 'mendi {{PLURAL:$1|$1}}',
'viewprevnext'              => '($1 {{int:pipe-separator}} $2) ($3)',
'search-result-size'        => '$1 ({{PLURAL:$2|1 tkvala|$2 tkvala}})',
'search-redirect'           => '(redirektʼi $1)',
'search-section'            => '(burme $1)',
'search-suggest'            => 'Aya çʼari-i: $1',
'search-interwiki-caption'  => 'Cuma projepe',
'search-interwiki-default'  => '$1 sonucepe:',
'search-interwiki-more'     => '(çkva)',
'search-mwsuggest-enabled'  => 'okʼvandupete',
'search-mwsuggest-disabled' => 'okʼvandu varen',
'nonefound'                 => "'''Notʼi''': Xvala, namtini svacoxope maartani oqʼopinot igoren.
Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (oğarğaluşi butʼkʼape, şablonepe, doçkva şeyepeti iqʼvasen) mgori varna pʼrefiksi oqʼopinot na igoren svacoxo ixmarit.",
'powersearch'               => 'Mordineri ogoru',
'powersearch-legend'        => 'Mordineri ogoru',
'powersearch-ns'            => 'Svacoxo-s mgori:',
'powersearch-redir'         => 'Redirektʼepe ilistʼeli',
'powersearch-field'         => 'Mgori:',

# Preferences page
'preferences'               => 'Tercihepe',
'mypreferences'             => 'Çkimi tercihepe',
'searchresultshead'         => 'Mgori',
'timezoneregion-africa'     => "Afrik'a",
'timezoneregion-antarctica' => "Antartik'a",
'timezoneregion-asia'       => 'Asya',
'timezoneregion-europe'     => "Avrop'a",
'youremail'                 => 'E-maili:',
'yourrealname'              => 'Coxo skani:',
'yourlanguage'              => 'Nena skani:',
'gender-male'               => "Biç'i",
'gender-female'             => "Bozo (K'ulani)",
'email'                     => 'E-maili',

# Groups
'group'       => 'Grubi:',
'group-sysop' => 'Adminepe',

'grouppage-sysop' => '{{ns:project}}:Adminepe',

# Rights
'right-delete' => 'Am sayfape jili',

# User rights log
'rightslog'  => 'Maxmareş hakʼişi kʼayitʼepe',
'rightsnone' => '(Va ren)',

# Associated actions - in the sentence "You do not have permission to X"
'action-read'   => "am sayfa ik'itxi",
'action-edit'   => 'am butʼkʼa oktiruşa',
'action-delete' => 'am sayfa dokosi',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|oktiroba|oktiroba}}',
'recentchanges'                  => 'Çodinaşi oktirobape',
'recentchanges-legend'           => 'Çodinaşi oktirobape tercihepe',
'recentchanges-feed-description' => 'Am feedis vikiʼs na ixvenu irişen sonni oktirobape gatxozi.',
'rcnote'                         => "$4 tarixi do saatʼi $5 şakis, çodinaşi {{PLURAL:$2|1 ndğas|'''$2''' ndğas}} na ixvenu, {{PLURAL:$1|'''1''' oktiroba|'''$1''' oktiroba}}, tude ren.",
'rclistfrom'                     => '$1 tarixişen doni na ixvenu oktirobape ko3ʼiri',
'rcshowhideminor'                => 'çʼitʼa oktirobape $1',
'rcshowhidebots'                 => 'botʼepe $1',
'rcshowhideliu'                  => 'meçʼareri maxmarepe $1',
'rcshowhideanons'                => 'anonimuri maxmarepe $1',
'rcshowhidemine'                 => 'çkimi oktirobape $1',
'rclinks'                        => 'Çodinaşi $2 ndğas na ixvenu çodinaşi $1 oktiroba ko3ʼiri;<br /> $3',
'diff'                           => 'farkʼi',
'hist'                           => 'tarixi',
'hide'                           => 'Doşinaxi',
'show'                           => 'Ko3ʼiri',
'minoreditletter'                => 'çʼ',
'newpageletter'                  => 'A',
'boteditletter'                  => 'b',
'rc_categories_any'              => 'Çkar',
'rc-enhanced-expand'             => 'Detayepe ko3ʼiri (JavaScript-i unon)',
'rc-enhanced-hide'               => 'Detayepe doşinaxi',

# Recent changes linked
'recentchangeslinked'         => 'Alakʼali na renan oktirobape',
'recentchangeslinked-title'   => '"$1" kʼala alakʼali na renan oktirobape',
'recentchangeslinked-summary' => "Tude na çʼars listʼe, kʼiti na noğiru butʼkʼaşa (varna kʼiti na noğiru kʼatʼegorişi makʼaturepeşa) kʼontʼaktʼi na ikips butʼkʼapes na ixvenu çodinaşi oktirobapeşi listʼe ren.
[[Special:Watchlist|Gotxozu na ginon butʼkʼapeşi listʼes]] na renan butʼkʼape '''mçxu''' nçʼaraten niçʼaru.",
'recentchangeslinked-page'    => 'Butʼkʼaşi coxo:',
'recentchangeslinked-to'      => 'Na niçinen butʼkʼa yeine na niçinen butʼkʼaşa kʼontʼaktʼi meçameri na renan butʼkʼape ko3ʼiri',

# Upload
'upload'        => 'Dosya doloxe kamaxvi',
'uploadlogpage' => 'Dosya oncğonu kʼayitʼepe',
'uploadedimage' => 'Siteşa na incğonen resimi: "[[$1]]"',

# File description page
'filehist'                  => 'Dosyaşi tarixi',
'filehist-help'             => 'Dosyaşi tarixi oz*iru şeni Ndğa/Ora burme-muşis na renan tarixepes o3ʼkʼedi.',
'filehist-deleteall'        => 'mteli jili',
'filehist-deleteone'        => 'jili',
'filehist-current'          => 'A3ʼineri',
'filehist-datetime'         => 'Dğa/Ora',
'filehist-thumb'            => 'Mçʼitʼa sureti',
'filehist-thumbtext'        => '$1 tarixis na iz*iren versiyonişi mçʼitʼa na ren xali',
'filehist-user'             => 'Maxmare',
'filehist-dimensions'       => 'Ebatʼepe',
'filehist-comment'          => 'Kʼommentʼi',
'imagelinks'                => 'Dosyaşi kʼontaktʼepe',
'linkstoimage'              => 'Am oz*ira-dosyaşa kʼontʼaktʼi na ikips {{PLURAL:$1|butʼkʼa|$1 butʼkʼa}}:',
'sharedupload'              => 'Am dosya $1-şen moxtu do belkim majurani pʼrojepesti ixmarinen.',
'uploadnewversion-linktext' => 'Dosyaşi ağani versiyoni doloxe kamaxvi',

# Statistics
'statistics' => 'İstatistʼiğepe',

'brokenredirects-edit'   => 'doktiri',
'brokenredirects-delete' => 'jili',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|byte|byte}}',
'nmembers'      => '{{PLURAL:$1|makʼature|makʼaturepe}}',
'prefixindex'   => 'Pʼrefiksi kʼala mteli butʼkʼape',
'newpages'      => 'Ağani butʼkʼape',
'move'          => 'Komendiği',
'movethispage'  => 'Butʼkʼa zdi',
'pager-newer-n' => '{{PLURAL:$1|çkva ağani 1|çkva ağani $1}}',
'pager-older-n' => '{{PLURAL:$1|çkva mcveşi 1|çkva mcveşi $1}}',

# Book sources
'booksources'               => 'Odude svarape',
'booksources-search-legend' => 'Svaraş odudepe mgori',
'booksources-go'            => 'İgzali',

# Special:Log
'log' => 'Kʼayitʼepe',

# Special:AllPages
'allpages'       => 'Mteli butʼkʼape',
'alphaindexline' => '$1 butʼkʼa muşişen $2 butʼkʼa muşişa',
'prevpage'       => 'İptineri butʼkʼa ($1)',
'allpagesfrom'   => 'Olistʼeluşa na geiçʼkʼasen harfepe:',
'allpagesto'     => 'Amu kʼala na içodu butʼkʼape ko3ʼiri:',
'allarticles'    => 'Mteli butʼkʼape',
'allpagessubmit' => 'İgzali',

# Special:LinkSearch
'linksearch' => 'Galeni kʼontaktʼepe',

# Special:Log/newusers
'newuserlogpage'          => 'Ağani maxmareş kʼayitʼepe',
'newuserlog-create-entry' => 'Ağani maxmare',

# Special:ListGroupRights
'listgrouprights-members' => '(makʼaturepeşi listʼe)',

# E-mail user
'emailuser' => 'Maxmares e-maili oncğoni',

# Watchlist
'watchlist'         => 'çkimi gotxozu listʼe',
'mywatchlist'       => 'Çkimi gotxozu listʼe',
'addedwatchtext'    => '"<nowiki>[[:$1]]</nowiki>" coxoni butʼkʼa [[Special:Watchlist|gotxozu listʼes]] ikʼayitʼinu.

Na moxtasen oras, am butʼkʼaşa do am butʼkʼa kʼala alakʼali na ren oğarğaluşi butʼkʼaşa na ixvenasen oktirobape ak ilistʼelinasen.

Dido kʼai o3xunu şeni doloxe muşis [[Special:RecentChanges|çodinaşi oktirobapeşi listʼe]] stʼatʼias dolom3ʼkʼupineri harfepete ilistʼelinasenan.

Butʼkʼai gotxozu listʼeşen ojilu şeni "gotxozu naşkʼvi" linkʼişa gebaz*git.',
'removedwatchtext'  => '"[[:$1]]" but\'k\'a, [[Special:Watchlist|skani gotxozu list\'eşen]] nijilu.',
'watch'             => 'Amus gatxozi',
'watchthispage'     => 'Butʼkʼa gatxozi',
'unwatch'           => 'Gotxozu naşkʼvi',
'watchlist-details' => '{{PLURAL:$1|$1 butʼkʼa|$1 butʼkʼa}}, skani gotxozu listʼes ren, ama oğarğaluşi butʼkʼapes va ren',
'wlshowlast'        => 'Çodinaşi $1 saatʼi $2 ndğa ko3ʼiri $3',
'watchlist-options' => 'Gotxozu listʼeşi tercihepe',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'i3ʼkʼedinen...',
'unwatching' => 'var i3ʼkʼedinen...',

# Delete
'deletepage'            => 'Butʼkʼa jili',
'confirmdeletetext'     => 'Aşoten am butʼkʼa varna dosya, mteli golaxteri kʼayitʼepe kʼala datʼabeizişen nijilen.
Am dulyaşen na yeçkindasen zararepe giçkinna do am dulya [[{{MediaWiki:Policy-url}}|Ojiluşi kʼaidepe]] şeni mtini renya isimadep na, am dulya doqʼvi.',
'actioncomplete'        => 'Aksiyoni içodinu.',
'deletedtext'           => '"$1" nijilu.
Xolosi oras jileri na renanpe oz*iru şeni: $2.',
'deletedarticle'        => '"[[$1]]" aya nijilu',
'dellogpage'            => 'Ojiluşi kʼayitʼepe',
'deletecomment'         => 'Muşen:',
'deleteotherreason'     => 'Majurani/ilave sebebi:',
'deletereasonotherlist' => 'Majurani sebebepe',

# Rollback
'rollbacklink' => 'mcveşi xali muşişa igzali',

# Protect
'protectlogpage'              => 'Oçvaluşi kʼayitʼepe',
'protectedarticle'            => '"[[$1]]" içven a3ʼi',
'modifiedarticleprotection'   => '"[[$1]]" şeni oçvaluşi derece iktirinu',
'protectcomment'              => 'Sebebi:',
'protectexpiry'               => 'Am tarixis içoden:',
'protect_expiry_invalid'      => 'Am tarixis var içoden, mtini va ren.',
'protect_expiry_old'          => 'Golaxteris soni oxmaruşi ora.',
'protect-text'                => "'''$1''' butʼkʼaşi oçvaluşi sinori akolen gazʼiren do gaktirinen.",
'protect-locked-access'       => "Butʼkʼaşi oçvalu sinorepe oktiru şeni maxmare-hesabi skanis yetʼkʼi var uğun.
'''$1''' butʼkʼaşi maartani tercihepe antepe renan:",
'protect-cascadeon'           => 'Am butʼkʼa, "kʼademoni oçvuşi sistemi" aktʼifi na ixvenu do tude na ren {{PLURAL:$1|$1 butʼkʼas|$1 butʼkʼas}} na ixmarinetʼu şeni a3ʼi içven.
Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvaluşa mutu va ikips.',
'protect-default'             => 'Mteli maxmarepes izni komeçi',
'protect-fallback'            => '"$1" izni unon',
'protect-level-autoconfirmed' => 'Ağani do kʼayitʼoni na va renan kʼoçepes bloği qʼvi',
'protect-level-sysop'         => 'Xvala, Adminepe şeni',
'protect-summary-cascade'     => 'kʼademoni',
'protect-expiring'            => 'çodinaşi tarixi $1 (UTC)',
'protect-cascade'             => 'Am butʼkʼas na ixmarinen mteli butʼkʼape içvi (kʼademoni oçvalu)',
'protect-cantedit'            => 'Am butʼkʼaşi oçvaluşi sinori va gaktirinen, çunki yetkʼi var giğun.',
'restriction-type'            => 'İzini:',
'restriction-level'           => 'Om3ikanuşi sinori:',

# Undelete
'undeletelink'              => 'i3ʼkʼedi/komoiği',
'undeletedarticle'          => '[[$1]] goiktu.',
'undelete-search-submit'    => 'Mgori',
'undelete-show-file-submit' => 'Ho',

# Namespace form on various pages
'namespace'      => 'Svacoxo:',
'invert'         => '3xuneri na var renanpe ko3ʼiri',
'blanknamespace' => '(Dudi)',

# Contributions
'contributions'       => 'Maxmareşi meşvelape',
'contributions-title' => '$1 şeni maxmareş meşvelape',
'mycontris'           => 'Çkimi meşvelape',
'contribsub2'         => '$1 ($2)',
'uctop'               => '(dudi)',
'month'               => 'Tuta:',
'year'                => '3ʼana:',

'sp-contributions-newbies'  => 'Xvala ağani maxmarepeşi meşvelape ko3ʼiri',
'sp-contributions-blocklog' => 'Bloğiş kʼayitʼi',
'sp-contributions-search'   => 'Meşvelape mgori',
'sp-contributions-username' => 'IP varna maxmare:',
'sp-contributions-submit'   => 'Mgori',

# What links here
'whatlinkshere'            => 'Butʼkʼaşa na ixvenu kʼontʼaktʼepe',
'whatlinkshere-title'      => '"$1" maddeşa kʼontʼaktʼi na ikips butʼkʼape',
'whatlinkshere-page'       => 'Butʼkʼa:',
'linkshere'                => "'''[[:$1]]''' butʼkʼaşa kʼontʼaktʼi na ikips butʼkʼape:",
'isredirect'               => 'redirektʼiş butʼkʼa',
'istemplate'               => 'okʼatu',
'isimage'                  => 'dosyaşi kʼontʼaktʼi',
'whatlinkshere-prev'       => '{{PLURAL:$1|ukʼuni|ukʼuni $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|mendi|mendi $1}}',
'whatlinkshere-links'      => '← kʼontaktʼepe',
'whatlinkshere-hideredirs' => 'redirektʼepe $1',
'whatlinkshere-hidetrans'  => 'Çʼapʼrazi mem3xverepe $1',
'whatlinkshere-hidelinks'  => 'kʼontʼaktʼepe $1',
'whatlinkshere-filters'    => 'Filitʼrepe',

# Block/unblock
'blockip'                  => 'Maxmares bloği qʼvi',
'ipboptions'               => '2 saatʼi:2 hours,1 ndğa:1 day,3 ndğa:3 days,1 doloni:1 week,2 doloni:2 weeks,1 tuta:1 month,3 tuta:3 months,6 tuta:6 months,1 3ʼana:1 year,pʼanda:infinite',
'ipblocklist'              => 'Bloği xveneri na renan IP adresepe do maxmareş coxope',
'blocklink'                => 'bloği qʼvi',
'unblocklink'              => 'bloği kezdi',
'change-blocklink'         => 'bloği doktiri',
'contribslink'             => 'Meşvelape',
'blocklogpage'             => 'Bloğiş kʼayitʼepe',
'blocklogentry'            => ', [[$1]] maxmare kododginu, dodginuşi ora: $2 $3',
'unblocklogentry'          => '$1 maxmareşi bloği kaizdinu',
'block-log-flags-nocreate' => 'hesabi okʼidu geinkʼilu',

# Move page
'movepagetext'     => "Tude na ren formi oxmarute butʼkʼaşi coxo iktirinen. Edo xolo mteli golaxteri kʼayitʼepeti ağani coxos itiren.
Mcveşi coxo, ağani coxoşa redirektʼi xali aqʼven.
Otomatikurot mcveşi stʼatʼiaşa na ixvenen redirektʼepe gaktirinen.
Am dulya otomatikurot oxvenu va ginonna [[Special:DoubleRedirects|tʼkʼubi]] varna [[Special:BrokenRedirects|tʼaxeri]] na renan redirektʼepe ti-skani kʼala oktiruşi re. Na qʼvare am oktirobate mteli kʼontʼaktʼepe dido kʼai oçalişu ren, amuşen si sorumli re.

Eger ağani coxos ar butʼkʼa zate korenna coxoşi oktiroba '''var ixvenasen'''. Amuş metʼi, coxoşi oktirobaşen pişmani qʼvi na, am oktiroba ipʼtʼali gaxvenen, aşoten başka butʼkʼapeşati zarari meçameri va gaqʼven.

'''KʼUN3Xİ!'''
Am ktira, populeri na ren a butʼkʼa şeni pʼatʼi mutxanepe axvenen; mu iqʼven ipti, aya giçkitʼas do ukʼule mutxanepe doktiri.",
'movepagetalktext' => "Okʼokʼatineri na ren oğarğaluşi butʼkʼati (eger korenna) otʼomatikurot ağani coxos itirinasen. Mara am situa3yonepes '''var itirinen''':

*Ağani coxos ar oğarğaluşi butʼkʼa zaten korenna,
*Tude na ren çʼitʼa boksi va ixmarit na.

Am situa3yonepes, butʼkʼa skanişkʼelen otiruşi ren.",
'movearticle'      => 'Mcveşi coxo:',
'newtitle'         => 'Ağani coxo:',
'move-watch'       => 'Am butʼkʼa gatxozi',
'movepagebtn'      => 'Coxo-muşi doktiri',
'pagemovedsub'     => 'Coxo iktirinu.',
'movepage-moved'   => '\'\'\'"$1",  "$2" butʼkʼa muşişa itirinu\'\'\'',
'articleexists'    => 'Am coxos ar butʼkʼa koren varna na çʼari coxo mtini va ren.
Mu iqʼven başka coxo doçʼari.',
'talkexists'       => "'''Butʼkʼa dido kʼai itirinu, mara oğarğaluşi butʼkʼa var itirinu çunki na itirinasen coxos zate ar butʼkʼa rtʼu. Mu iqʼven butʼkʼaşi doloçʼareli nç'arape majurani butʼkʼaşa ti-skani kʼala itirini.'''",
'movedto'          => 'itirinu:',
'movetalk'         => 'Korenna, "oğarğaluşi" butʼkʼa muşiti mendiği.',
'1movedto2'        => '[[$1]] butʼkʼa muşişi ağani coxo: [[$2]]',
'1movedto2_redir'  => '[[$1]] stʼatʼiaşi adresi iktirinu do ağani adresi [[$2]] butʼkʼaşa niçinu',
'movelogpage'      => 'Coxo oktirobaşi kʼayitʼepe',
'movereason'       => 'Muşen:',
'revertmove'       => 'komoiği',

# Export
'export' => 'Butʼkʼa ikʼayitʼi',

# Thumbnails
'thumbnail-more' => 'Didi qʼvi',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Skani butʼkʼa',
'tooltip-pt-mytalk'               => 'Mesajiş butʼkʼa',
'tooltip-pt-preferences'          => 'Skani tercixepe',
'tooltip-pt-watchlist'            => 'Gotxozu na minon butʼkʼape',
'tooltip-pt-mycontris'            => 'Skani meşvelapeşi listʼe',
'tooltip-pt-login'                => 'Ginon na sitʼeşa amaxti, mecburi va re',
'tooltip-pt-logout'               => 'Siteşen Kogamaxti',
'tooltip-ca-talk'                 => 'Butʼkʼaş doloxe na içʼaren çʼarape şeni mutxanepe mi3ʼvit',
'tooltip-ca-edit'                 => 'Am butʼkʼa kodogaktiren. Mu iqʼven! ipti "Evvelişen i3ʼkʼedi" tʼuşi ixmari do na çʼari çʼara ikʼontʼroli, ukʼule ikʼayitʼi.',
'tooltip-ca-addsection'           => 'Ağani burme dokʼidi.',
'tooltip-ca-viewsource'           => 'Am butʼkʼa içven. Xvala odudeş kʼodi gaz*iren. Doloxe muşi va gaktirinen.',
'tooltip-ca-history'              => 'Am butʼkʼaşi golaxteri versiyonepe',
'tooltip-ca-protect'              => 'Am butʼkʼa içvi',
'tooltip-ca-delete'               => 'Am sayfa jili',
'tooltip-ca-move'                 => 'Butʼkʼaşi coxo doktiri',
'tooltip-ca-watch'                => 'Am butʼkʼas gatxozi.',
'tooltip-ca-unwatch'              => 'Skani gotxozu listʼeşen jili am butʼkʼa',
'tooltip-search'                  => '{{SITENAME}}-iş doloxe mgori',
'tooltip-search-go'               => 'Eger korenna, am coxos na uğun ar butʼkʼaşa idi',
'tooltip-search-fulltext'         => 'Am nçʼara şeni butʼkʼape mgori',
'tooltip-n-mainpage'              => 'Dudi butʼkʼaşa idi',
'tooltip-n-mainpage-description'  => 'Dudi butʼkʼaşa idi',
'tooltip-n-portal'                => 'Proje şeni, şeyepe so gaz*iren, mu gaxvenen',
'tooltip-n-currentevents'         => 'Ağani oğodape şeni çodinaşi çkinape',
'tooltip-n-recentchanges'         => 'Vikʼis na ixvenu sonni oktirobapeşi listʼe.',
'tooltip-n-randompage'            => 'Na var giçkin a butʼkʼaşa idi.',
'tooltip-n-help'                  => 'Meşvelaş yezdimu şeni',
'tooltip-t-whatlinkshere'         => 'Am butʼkʼaşa kʼontʼaktʼi na ikips majurani vikʼiş butʼkʼapeşi listʼe',
'tooltip-t-recentchangeslinked'   => 'Am butʼkʼaşa kʼontʼaktʼi na ikips butʼkʼapes, çodinaşi oktirobape',
'tooltip-feed-rss'                => 'Am butʼkʼa şeni RSS-iş feedi',
'tooltip-feed-atom'               => 'Am butʼkʼa şeni atʼom-iş feedi',
'tooltip-t-contributions'         => 'Maxmareşi meşvela listʼe kozʼiri',
'tooltip-t-emailuser'             => 'Maxmareşa e-maili oncğoni',
'tooltip-t-upload'                => 'Dosyape doloxe kamaxvi',
'tooltip-t-specialpages'          => 'Mteli doxmeli butʼkʼapeşi listʼe ko3ʼiri',
'tooltip-t-print'                 => 'Am butʼkʼaşi kartʼalişa çʼareli na ren versiyoni',
'tooltip-t-permalink'             => 'Am butʼkʼaşi am versiyoni muşis kʼarta ora kʼontʼaktʼi iqʼvi.',
'tooltip-ca-nstab-main'           => 'Butʼkʼa ko3ʼiri',
'tooltip-ca-nstab-user'           => 'Maxmareşi butʼkʼa ko3ʼiri',
'tooltip-ca-nstab-special'        => 'Aya doxmeli butʼkʼa ren, emuşeni ak mutu va gaktirinen.',
'tooltip-ca-nstab-project'        => 'Pʼrojeşi butʼkʼa ko3ʼiri',
'tooltip-ca-nstab-image'          => 'Dosyaşi butʼkʼa ko3ʼiri',
'tooltip-ca-nstab-template'       => 'Şabloni ko3ʼiri',
'tooltip-ca-nstab-category'       => 'Kʼatʼegorişi butʼkʼa ko3ʼiri',
'tooltip-minoredit'               => 'Aşoten "Çʼitʼa oktiroba" gaxvenen',
'tooltip-save'                    => 'Oktirobape ikʼayitʼi',
'tooltip-preview'                 => 'Evvelişen i3ʼkʼedi; ipti am fonkʼsioni ixmari, oktirobape kʼontʼroli qʼvi do ukʼule ikʼayitʼi!',
'tooltip-diff'                    => 'Tekstʼişa na qʼvi oktirobape o3ʼiraps.',
'tooltip-compareselectedversions' => '3xuneri na ren jur versiyonişi oşkendas na renan farkʼepe ko3ʼiri.',
'tooltip-watch'                   => 'Am butʼkʼa gatxozi',
'tooltip-rollback'                => '"Ukʼuni" fonkʼsionik, ar gebaz*gute, am butʼkʼas na nuşvelu maxmareşi oktirobape ipʼtʼali ikips',
'tooltip-undo'                    => '"Ukʼuni" am fonkʼsionik, oktirobape ipʼtʼali ikips do aşoten oktirobaşi formi, "Evvelişen i3ʼkʼedi" modis guin3ʼkʼen.
"Mkʼule nçʼarate" fonkʼsioni şeni ar sebebi okʼum3xus izni meçaps',

# Browsing diffs
'previousdiff' => '← İptineri versiyoni kʼala na ren farkʼi',
'nextdiff'     => 'Ukʼaçxineri versiyoni kʼala na ren farkʼi →',

# Media information
'file-info-size' => '$1 × $2 pikseli, dosyaşi didinoba: $3, MIME type: $4',
'file-nohires'   => '<small>Çkva kʼai ozʼiramuşis na uğun versiyoni va ren.</small>',
'svg-long-desc'  => 'SVG dosya, coxoten $1 × $2 pʼikʼseli, dosyaşi didinoba: $3',
'show-big-image' => 'Tam ozʼiramuşi',

# Bad image list
'bad_image_list' => 'Formatʼi aşo ren:

Xvala listeşi dudi ondepe (* kʼala na gyoçʼkʼaps ondepe) beciti ren.
Satʼirişi maartani kʼontʼaktʼi, pʼatʼi dosyaşa na ulun ar kʼontʼaktʼi oqʼopinu dvaçʼirs.
Ukʼaçxe na mulunan kʼontʼaktʼepe istʼisna oqʼopinot kʼabuli ixvenen. Mesela: dosya, butʼkʼas, satʼiriş doloxe iz*iren.',

# Metadata
'metadata'          => 'Metadata',
'metadata-help'     => 'Am dosyas, suretişi mangana varna mao3xoneşkʼelen kʼatineri na ren okʼum3vale çkinape koren. Eger dosyaşi originali xalişa modifiye na iqʼu na, namtini çkinape, ağani oktiroba şeni mcveşi doskideri iqʼopen.',
'metadata-expand'   => 'Detayepe ko3ʼiri',
'metadata-collapse' => 'Detayepe doşinaxi',
'metadata-fields'   => 'Am butʼkʼas na ilistʼelinen EXIF metadataş burmepe, resimi ozʼiramuşi butʼkʼapes metadata tʼablo na ğuru oras ixmarinen. Majuranepeti maartani oqʼopinot işinaxasen.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Dosyas, kʼompʼuteris na renan pʼrogramepe kʼala oktirobape doqʼvi.',
'edit-externally-help' => '(Dido çkina şeni metʼas na renan [//www.mediawiki.org/wiki/Manual:External_editors galeni xvenaş tercihepe] (İngilisuri) butʼkʼa muşis o3ʼkʼedit)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'mteli',
'namespacesall' => 'mteli',
'monthsall'     => 'mteli',

# Watchlist editing tools
'watchlisttools-view' => 'Am tema kʼala alakʼali na renan oktirobape ko3ʼiri',
'watchlisttools-edit' => 'Gotxozu listʼe koz*iri do doktiri',
'watchlisttools-raw'  => 'Kʼobo gotxozu listʼe doktiri',

# Special:SpecialPages
'specialpages' => 'Doxmeli butʼkʼape',

);
